// src/index.ts
import { execSync } from "child_process";
import { existsSync } from "fs";
import { createFilter } from "@rollup/pluginutils";
import MagicString from "magic-string";
var getCommit = () => {
  try {
    return encodeURIComponent(
      execSync("git describe --long --always --dirty --abbrev=10000").toString().trim()
    );
  } catch (error) {
    if (!existsSync(".git")) {
      return ".git-not-found";
    } else {
      console.warn("nonfatal<git>: Git errored", error);
      return "unknown-commit";
    }
  }
};
var commit = getCommit();
var commitExpires = Date.now() + 1e4;
var virtualModuleId = "virtual:commit-hash";
var resolvedVirtualModuleId = "\0" + virtualModuleId;
var cachedCommitId = () => {
  if (Date.now() > commitExpires) {
    commit = getCommit();
    commitExpires = Date.now() + 1e4;
  }
  return commit;
};
var CommitHashPlugin = (config = { noPrefix: false, noVirtual: false }) => {
  const filter = createFilter(["**/*.js", "**/*.css"], null, {
    resolve: false
  });
  return {
    name: "ExponentialWorkload: Git Commit Hash",
    transform(code, id) {
      if (!filter(id))
        return null;
      const commit2 = cachedCommitId();
      const s = new MagicString(code);
      if (id.endsWith(".css")) {
        s.prepend(`/** Commit ${commit2} **/
`);
      } else if (id.endsWith(".js")) {
        s.prepend(`// Commit ${commit2}
`);
      }
      const map = s.generateMap({
        source: id,
        hires: true
      });
      return { code: s.toString(), map };
    },
    resolveId(id) {
      if (!config.noVirtual && id === virtualModuleId) {
        return resolvedVirtualModuleId;
      }
    },
    load(id) {
      if (!config.noVirtual && id === resolvedVirtualModuleId) {
        return `export const id = '${cachedCommitId()}';
export default id;
`;
      }
    }
  };
};
var src_default = CommitHashPlugin;
export {
  CommitHashPlugin,
  src_default as default
};
